import yaml
import json

from si_tests import settings
from si_tests import logger
import si_tests.utils.templates as utils

LOG = logger.logger


def test_openstack_controller_functional(os_manager):
    """Run functional openstack controller tests"""
    pod = None
    try:
        templates = utils.render_template(settings.OPENSTACK_CONTROLLER_TESTS_POD_TEMPLATE)
        LOG.debug(templates)
        json_body = json.dumps(yaml.load(templates, Loader=yaml.SafeLoader))
        pod = os_manager.api.pods.create(
            name=settings.OPENSTACK_CONTROLLER_TESTS_POD_NAME,
            namespace=settings.OPENSTACK_CONTROLLER_TESTS_POD_NAMESPACE,
            body=json.loads(json_body))
        pod.wait_phase('Running')
        pod.wait_test(filepath='./test_*', timeout=settings.OPENSTACK_CONTROLLER_TESTS_TIMEOUT)
        pod.cp_from_pod(source_dir="/var/lib/tests/", compression="-z")

        os_manager.wait_os_deployment_status(timeout=900, status="APPLIED")
        os_manager.wait_osdpl_services()

        LOG.info("Wait until all services in health section"
                 " get status `Ready`")
        os_manager.wait_openstackdeployment_health_status()

        LOG.info("Check that OpenStack pods are active.")
        os_manager.wait_os_resources(timeout=settings.OPENSTACK_LCM_OPERATIONS_TIMEOUT, interval=20)
    finally:
        if pod is not None:
            pod.delete()
